package com.zjrs.ggfw.sggfw.bpo.impl;

import com.zjrs.ggfw.sggfw.blo.RlzyscSjsbBLO;
import com.zjrs.ggfw.sggfw.bpo.RlzyscSjsbBPO;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;

@Service
public class RlzyscSjsbBPOImpl implements RlzyscSjsbBPO {

    @Resource
    private RlzyscSjsbBLO rlzyscSjsbBLO;

    @Override
    public void grJlxxSb(String OperType) {
        rlzyscSjsbBLO.grJlxxSb(OperType);
    }

    @Override
    public void grQzdjSb(String OperType) {
       rlzyscSjsbBLO.grQzdjSb(OperType);
    }

    @Override
    public void grQzyxSb(String OperType) {
         rlzyscSjsbBLO.grQzyxSb(OperType);
    }

    @Override
    public void dwZpxxSb(String OperType) {
         rlzyscSjsbBLO.dwZpxxSb(OperType);
    }

    @Override
    public void zphxxSb(String OperType) {
       rlzyscSjsbBLO.zphxxSb(OperType);
    }

    @Override
    public void xyUpdateOrDelGrJbxx(String OperType) {
        this.rlzyscSjsbBLO.xyUpdateOrDelGrJbxx(OperType);
    }

    @Override
    public void xyUpdateOrDelDwJbxx(String OperType) {
        this.rlzyscSjsbBLO.xyUpdateOrDelDwJbxx(OperType);
    }



}
