package com.zjrs.ggfw.sggfw.schedule;

import jakarta.annotation.Resource;
import com.zjrs.ggfw.sggfw.bpo.RlzyscSjsbBPO;

public class RlzySjsbSchedule {

    @Resource
    private RlzyscSjsbBPO rlzyscSjsbBPO;

//    @Scheduled(cron = "0 */1 * * * ?")
//    public void SaveGrjlxx() {
//        rlzyscSjsbBPO.grJlxxSb("INS");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void SaveGrQzyxSb() {
//        rlzyscSjsbBPO.grQzyxSb("INS");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void SaveGrQzdj() {
//        rlzyscSjsbBPO.grQzdjSb("INS");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void SavedwZpxxSb() {
//        rlzyscSjsbBPO.dwZpxxSb("INS");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void SaveZphxx() {
//        rlzyscSjsbBPO.zphxxSb("INS");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateGrjlxx() {
//        rlzyscSjsbBPO.grJlxxSb("UPD");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateGrQzyxSb() {
//        rlzyscSjsbBPO.grQzyxSb("UPD");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateGrQzdj() {
//        rlzyscSjsbBPO.grQzdjSb("UPD");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updatedwZpxxSb() {
//        rlzyscSjsbBPO.dwZpxxSb("UPD");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateZphxx() {
//        rlzyscSjsbBPO.zphxxSb("UPD");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void delGrjlxx() {
//        rlzyscSjsbBPO.grJlxxSb("DEL");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void delGrQzyxSb() {
//        rlzyscSjsbBPO.grQzyxSb("DEL");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void delGrQzdj() {
//        rlzyscSjsbBPO.grQzdjSb("DEL");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void deldwZpxxSb() {
//        rlzyscSjsbBPO.dwZpxxSb("DEL");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void delZphxx() {
//        rlzyscSjsbBPO.zphxxSb("DEL");
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateGrjbxx() {
//        rlzyscSjsbBPO.xyUpdategrJbxx();
//    }
//
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void updateDwjbxx() {
//        rlzyscSjsbBPO.xyUpdateDwJbxx();
//    }
}
